.lightdm.menu {
    background-image: none;
    background-color: alpha (black, 0.6);
    border-color: alpha (white, 0.2);
    border-radius: 4px;
    padding: 1px;

    color: white;
}

.lightdm-combo .menu {
    background-color: shade (@dark_bg_color, 1.08);
    border-radius: 0px;
    padding: 0px;

    color: white;
}

.lightdm.menu .menuitem *,
.lightdm.menu .menuitem.check:active,
.lightdm.menu .menuitem.radio:active {
    color: white;
}

.lightdm.menubar {
    background-image: none;
    background-color: alpha (black, 0.5);
}

.lightdm.button {
    border: 1px solid;
    background-image: none;
    background-color: alpha (black, 0.3);
    border-color: alpha (white, 0.6);
    border-radius: 5px;
    padding: 7px;

    color: white;
    text-shadow: none;
}

.lightdm.button,
.lightdm.button:hover,
.lightdm.button:active,
.lightdm.button:active:focused {
    background-image: none;
    border-image: none;
}

.lightdm.button:focused {
    border-color: alpha (white, 0.9);
    border-width: 1px;
    border-style: solid;

    color: white;
}

.lightdm-combo.combobox-entry .button,
.lightdm-combo .cell,
.lightdm-combo .button,
.lightdm-combo .entry,
.lightdm.entry {
    background-image: none;
    background-color: alpha (black, 0.3);
    border-color: alpha (white, 0.6);
    border-radius: 5px;
    padding: 7px;

    color: white;
    text-shadow: none;
}

.lightdm.entry,
.lightdm.entry:hover,
.lightdm.entry:active,
.lightdm.entry:active:focused {
    background-image: none;
    border-image: none;
}

.lightdm.entry:focused {
    border-color: alpha (white, 0.9);
    border-width: 1px;
    border-style: solid;

    color: white;
}

.lightdm.entry:selected {
    background-color: alpha (white, 0.2);
}

@keyframes dashentry_spinner {
    to { -gtk-icon-transform: rotate(1turn); }
}

.lightdm.entry:active {
    -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
    animation: dashentry_spinner 1s infinite linear;
}

.lightdm.option-button {
    padding: 2px;
    background: none;
    border-color: transparent;
}

.lightdm.toggle-button {
    background: none;
    border-color: transparent;
}

.lightdm.toggle-button.selected {
    background-color: alpha (black, 0.3);
    border-width: 1px;
}
